Neko 1.99.7
A portable framework for high-order spectral element flow simulations
Loading...
Searching...
No Matches
opr_cdtp.hip File Reference
#include <string.h>
#include <stdlib.h>
#include <stdio.h>
#include <hip/hip_runtime.h>
#include <device/device_config.h>
#include <device/hip/check.h>
#include "cdtp_kernel.h"
#include "elem_block_tune.h"
#include <common/neko_log.h>

Go to the source code of this file.

Macros

#define CASE_1D(LX, C)
 
#define CASE_1D_SEL(LX, SEL)
 
#define CASE_KSTEP(LX, C)
 
#define CASE_KSTEP_SEL(LX, SEL)
 
#define CASE(LX)
 
#define CASE_LARGE(LX)
 

Functions

template<const int >
int tune_cdtp (void *dtx, void *x, void *dr, void *ds, void *dt, void *dxt, void *dyt, void *dzt, void *w3, int *nel, int *lx, int *eb_sel, int *ch_sel)
 
void hip_cdtp (void *dtx, void *x, void *dr, void *ds, void *dt, void *dxt, void *dyt, void *dzt, void *w3, int *nel, int *lx)
 

Macro Definition Documentation

◆ CASE

#define CASE (   LX)
Value:
case LX: \
if(autotune[LX] == 0 ) { \
dr, ds, dt, \
dxt, dyt, dzt, \
w3, nel, lx, &autotune_eb[LX], \
} else if (autotune[LX] == 1 ) { \
} else if (autotune[LX] == 2 ) { \
} \
break
__global__ void ale_add_kinematics_kernel(const int n, T *__restrict__ wx, T *__restrict__ wy, T *__restrict__ wz, const T *__restrict__ x_ref, const T *__restrict__ y_ref, const T *__restrict__ z_ref, const T *__restrict__ phi, const T *__restrict__ x, const T *__restrict__ y, const T *__restrict__ z, const kinematics_params_t kin_params)
__global__ void const T *__restrict__ const T *__restrict__ dr
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ ds
__global__ void const T *__restrict__ x
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dt
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ w3
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dzt
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dyt
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dxt

◆ CASE_1D

#define CASE_1D (   LX,
  C 
)
Value:
(hipStream_t) glb_cmd_queue, \
(real *) dtx, (real *) x, \
(real *) dr, (real *) ds, (real *) dt, \
(real *) dxt, (real *) dyt, (real *) dzt, \
(real *) w3); \
__global__ void cdtp_kernel_1d(T *__restrict__ dtx, const T *__restrict__ x, const T *__restrict__ dr, const T *__restrict__ ds, const T *__restrict__ dt, const T *__restrict__ dxt, const T *__restrict__ dyt, const T *__restrict__ dzt, const T *__restrict__ w3)
Definition cdtp_kernel.h:44
#define NEKO_CHUNKS(LX, C)
Definition elem_block.h:145
#define NEKO_CHUNKS_NTHRDS(LX, C)
Definition elem_block.h:146
double real

◆ CASE_1D_SEL

#define CASE_1D_SEL (   LX,
  SEL 
)
Value:
switch (SEL) { \
case 0: CASE_1D(LX, 0); break; \
case 1: CASE_1D(LX, 1); break; \
case 2: CASE_1D(LX, 2); break; \
default: CASE_1D(LX, 3); break; \
}
#define CASE_1D(LX, C)

◆ CASE_KSTEP

#define CASE_KSTEP (   LX,
  C 
)
Value:
NEKO_EB_NBLCKS(*nel, LX, C), NEKO_EB_NTHRDS(LX, C), 0, \
(hipStream_t) glb_cmd_queue, \
(real *) dtx, (real *) x, \
(real *) dr, (real *) ds, (real *) dt, \
(real *) dxt, (real *) dyt, (real *) dzt, \
(real *) w3, *nel); \
#define NEKO_EB(LX, C)
Definition elem_block.h:104
#define NEKO_EB_NBLCKS(NELV, LX, C)
Definition elem_block.h:106
#define NEKO_EB_NTHRDS(LX, C)
Definition elem_block.h:105

◆ CASE_KSTEP_SEL

#define CASE_KSTEP_SEL (   LX,
  SEL 
)
Value:
switch (SEL) { \
case 0: CASE_KSTEP(LX, 0); break; \
case 1: CASE_KSTEP(LX, 1); break; \
default: CASE_KSTEP(LX, 2); break; \
}
#define CASE_KSTEP(LX, C)

◆ CASE_LARGE

#define CASE_LARGE (   LX)
Value:
case LX: \
break

Function Documentation

◆ hip_cdtp()

void hip_cdtp ( void dtx,
void x,
void dr,
void ds,
void dt,
void dxt,
void dyt,
void dzt,
void w3,
int nel,
int lx 
)

Fortran wrapper for device hip \( D^T X \)

Definition at line 59 of file opr_cdtp.hip.

Here is the call graph for this function:

◆ tune_cdtp()

template<const int >
int tune_cdtp ( void dtx,
void x,
void dr,
void ds,
void dt,
void dxt,
void dyt,
void dzt,
void w3,
int nel,
int lx,
int eb_sel,
int ch_sel 
)

Definition at line 171 of file opr_cdtp.hip.

Here is the call graph for this function: